@@ -48,15 +48,15 @@ image "storage-version-migration-serving-serving-$(metadata.get dependencies.ser
 
 image "kourier-gateway" "quay.io/openshift-knative/proxyv2-ubi8:$(metadata.get dependencies.maistra)"
 image "kourier-control" "${registry}/knative-v$(metadata.get dependencies.kourier):kourier"
+image "net-kourier-controller__controller" "${registry}/knative-v$(metadata.get dependencies.kourier):kourier"
 
-image "networking-istio" "${registry}/knative-v$(metadata.get dependencies.net_istio):net-istio-controller"
-image "istio-webhook__webhook" "${registry}/knative-v$(metadata.get dependencies.net_istio):net-istio-webhook"
+image "net-istio-controller__controller" "${registry}/knative-v$(metadata.get dependencies.net_istio):net-istio-controller"
+image "net-istio-webhook__webhook" "${registry}/knative-v$(metadata.get dependencies.net_istio):net-istio-webhook"
 
 image "eventing-controller__eventing-controller"    "${eventing}-controller"
 image "sugar-controller__controller"                "${eventing}-sugar-controller"
 image "eventing-webhook__eventing-webhook"          "${eventing}-webhook"
 image "storage-version-migration-eventing-eventing-$(metadata.get dependencies.eventing)__migrate" "${eventing}-storage-version-migration"
-image "pingsource-cleanup-eventing-$(metadata.get dependencies.eventing)__pingsource"              "${eventing}-pingsource-cleanup"
 image "mt-broker-controller__mt-broker-controller"  "${eventing}-mtchannel-broker"
 image "mt-broker-filter__filter"                    "${eventing}-mtbroker-filter"
 image "mt-broker-ingress__ingress"                  "${eventing}-mtbroker-ingress"
@@ -71,7 +71,6 @@ kafka_image "kafka-controller-manager__manager"    "${eventing_kafka}-source-con
 kafka_image "KAFKA_RA_IMAGE"                       "${eventing_kafka}-receive-adapter"
 kafka_image "kafka-ch-controller__controller"      "${eventing_kafka}-consolidated-controller"
 kafka_image "DISPATCHER_IMAGE"                     "${eventing_kafka}-consolidated-dispatcher"
-kafka_image "kafka-ch-dispatcher__dispatcher"      "${eventing_kafka}-consolidated-dispatcher"
 kafka_image "kafka-webhook__kafka-webhook"         "${eventing_kafka}-webhook"
 
 image "KUBE_RBAC_PROXY"   "${rbac_proxy}"
@@ -96,7 +95,7 @@ function add_related_image {
 EOF
 }
 
-function add_downstream_operator_deployment_image {
+function add_downstream_operator_deployment_env {
   cat << EOF | yq write --inplace --script - "$1"
 - command: update
   path: spec.install.spec.deployments(name==knative-openshift).spec.template.spec.containers(name==knative-openshift).env[+]
@@ -110,7 +109,7 @@ EOF
 # we don't add scope prefixes to image overrides here. We don't have a clash anyway without any scope prefixes!
 # there was a naming clash between eventing and kafka, but we won't provide the Kafka overrides to the
 # midstream operator.
-function add_upstream_operator_deployment_image {
+function add_upstream_operator_deployment_env {
   cat << EOF | yq write --inplace --script - "$1"
 - command: update
   path: spec.install.spec.deployments(name==knative-operator).spec.template.spec.containers(name==knative-operator).env[+]
@@ -126,17 +125,20 @@ cp "$template" "$target"
 for name in "${images[@]}"; do
   echo "Image: ${name} -> ${images_addresses[$name]}"
   add_related_image "$target" "IMAGE_${name}" "${images_addresses[$name]}"
-  add_downstream_operator_deployment_image "$target" "IMAGE_${name}" "${images_addresses[$name]}"
-  add_upstream_operator_deployment_image "$target" "IMAGE_${name}" "${images_addresses[$name]}"
+  add_downstream_operator_deployment_env "$target" "IMAGE_${name}" "${images_addresses[$name]}"
+  add_upstream_operator_deployment_env "$target" "IMAGE_${name}" "${images_addresses[$name]}"
 done
 
 # don't add Kafka image overrides to upstream operator
 for name in "${kafka_images[@]}"; do
   echo "kafka Image: ${name} -> ${kafka_images_addresses[$name]}"
   add_related_image "$target" "KAFKA_IMAGE_${name}" "${kafka_images_addresses[$name]}"
-  add_downstream_operator_deployment_image "$target" "KAFKA_IMAGE_${name}" "${kafka_images_addresses[$name]}"
+  add_downstream_operator_deployment_env "$target" "KAFKA_IMAGE_${name}" "${kafka_images_addresses[$name]}"
 done
 
+# Add Knative Kafka version to the downstream operator
+add_downstream_operator_deployment_env "$target" "KNATIVE_EVENTING_KAFKA_VERSION" "$(metadata.get dependencies.eventing_kafka)"
+
 # Override the image for the CLI artifact deployment
 yq write --inplace "$target" "spec.install.spec.deployments(name==knative-openshift).spec.template.spec.initContainers(name==cli-artifacts).image" "${registry}/knative-v$(metadata.get dependencies.cli):kn-cli-artifacts"
 
