@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"strings"
 
+	socommon "github.com/openshift-knative/serverless-operator/pkg/common"
 	routev1 "github.com/openshift/api/route/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
@@ -18,14 +19,14 @@ import (
 
 const (
 	TimeoutAnnotation                = "haproxy.router.openshift.io/timeout"
-	DisableRouteAnnotation           = "serving.knative.openshift.io/disableRoute"
-	EnablePassthroughRouteAnnotation = "serving.knative.openshift.io/enablePassthrough"
+	DisableRouteAnnotation           = socommon.ServingDownstreamDomain + "/disableRoute"
+	EnablePassthroughRouteAnnotation = socommon.ServingDownstreamDomain + "/enablePassthrough"
 
 	HTTPPort  = "http2"
 	HTTPSPort = "https"
 
-	OpenShiftIngressLabelKey          = "serving.knative.openshift.io/ingressName"
-	OpenShiftIngressNamespaceLabelKey = "serving.knative.openshift.io/ingressNamespace"
+	OpenShiftIngressLabelKey          = socommon.ServingDownstreamDomain + "/ingressName"
+	OpenShiftIngressNamespaceLabelKey = socommon.ServingDownstreamDomain + "/ingressNamespace"
 )
 
 // DefaultTimeout is set by DefaultMaxRevisionTimeoutSeconds. So, the OpenShift Route's timeout
@@ -111,6 +112,26 @@ func makeRoute(ci *networkingv1alpha1.Ingress, host string, rule networkingv1alp
 		return nil, ErrNoValidLoadbalancerDomain
 	}
 
+	terminationPolicy := routev1.InsecureEdgeTerminationPolicyAllow
+	if ci.Spec.HTTPOption == networkingv1alpha1.HTTPOptionRedirected {
+		terminationPolicy = routev1.InsecureEdgeTerminationPolicyRedirect
+	}
+
+	// TODO: Remove this annotation handling after serving 0.26+.
+	// Ingress configures the HTTPOption based on the annotation.
+	// https://github.com/knative/serving/commit/d9c1342b5761afdac88c563535885e37fae27c7e
+	if annotations[networking.HTTPOptionAnnotationKey] != "" {
+		annotation := annotations[networking.HTTPOptionAnnotationKey]
+		switch strings.ToLower(annotation) {
+		case "enabled":
+			terminationPolicy = routev1.InsecureEdgeTerminationPolicyAllow
+		case "redirected":
+			terminationPolicy = routev1.InsecureEdgeTerminationPolicyRedirect
+		default:
+			return nil, fmt.Errorf("incorrect HTTPOption annotation: " + annotation)
+		}
+	}
+
 	route := &routev1.Route{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:        name,
@@ -130,14 +151,16 @@ func makeRoute(ci *networkingv1alpha1.Ingress, host string, rule networkingv1alp
 			},
 			TLS: &routev1.TLSConfig{
 				Termination:                   routev1.TLSTerminationEdge,
-				InsecureEdgeTerminationPolicy: routev1.InsecureEdgeTerminationPolicyAllow,
+				InsecureEdgeTerminationPolicy: terminationPolicy,
 			},
 			WildcardPolicy: routev1.WildcardPolicyNone,
 		},
 	}
 
-	// If the passthrough annotation is set, target the HTTPS port and configure passthrough.
-	if _, ok := annotations[EnablePassthroughRouteAnnotation]; ok {
+	// Target the HTTPS port and configure passthrough when:
+	// * the passthrough annotation is set.
+	// * the ingress.spec.tls is set. (DomainMapping with BYP cert.)
+	if _, ok := annotations[EnablePassthroughRouteAnnotation]; ok || len(ci.Spec.TLS) > 0 {
 		route.Spec.Port.TargetPort = intstr.FromString(HTTPSPort)
 		route.Spec.TLS.Termination = routev1.TLSTerminationPassthrough
 		route.Spec.TLS.InsecureEdgeTerminationPolicy = routev1.InsecureEdgeTerminationPolicyRedirect
